@@ -321,7 +321,7 @@ class ImagingApi(object):
         return self.__make_request_async(http_request, 'POST', 'file')
 
     def create_image_frame_range(self, request):
-        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get frames range from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request create_image_frame_range_request object with parameters
@@ -331,7 +331,7 @@ class ImagingApi(object):
         return self.__make_request(http_request, 'POST', 'file')
 
     def create_image_frame_range_async(self, request):
-        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get frames range from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request create_image_frame_range_request object with parameters
@@ -580,6 +580,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'POST', 'file')
 
+    def create_object_bounds(self, request):
+        """Detects objects bounds. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_object_bounds_request object with parameters
+        :return: DetectedObjectList
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'POST', 'DetectedObjectList')
+
+    def create_object_bounds_async(self, request):
+        """Detects objects bounds. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_object_bounds_request object with parameters
+        :return: DetectedObjectList
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'POST', 'DetectedObjectList')
+
     def create_resized_image(self, request):
         """Resize an image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
@@ -660,6 +680,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'POST', 'file')
 
+    def create_visual_object_bounds(self, request):
+        """Detects objects bounds and draw them on the original image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream
+
+
+        :param request create_visual_object_bounds_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'POST', 'file')
+
+    def create_visual_object_bounds_async(self, request):
+        """Detects objects bounds and draw them on the original image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream
+
+
+        :param request create_visual_object_bounds_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'POST', 'file')
+
     def create_web_site_image_features(self, request):
         """Extract images features from web page and add them to search context
 
@@ -1160,6 +1200,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'GET', 'SearchContextStatus')
 
+    def get_object_bounds(self, request):
+        """Detects objects&#39; bounds
+
+
+        :param request get_object_bounds_request object with parameters
+        :return: DetectedObjectList
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'GET', 'DetectedObjectList')
+
+    def get_object_bounds_async(self, request):
+        """Detects objects&#39; bounds
+
+
+        :param request get_object_bounds_request object with parameters
+        :return: DetectedObjectList
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'GET', 'DetectedObjectList')
+
     def get_search_image(self, request):
         """Get image from search context
 
@@ -1180,6 +1240,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'GET', 'file')
 
+    def get_visual_object_bounds(self, request):
+        """Detects objects bounds and draw them on the original image
+
+
+        :param request get_visual_object_bounds_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'GET', 'file')
+
+    def get_visual_object_bounds_async(self, request):
+        """Detects objects bounds and draw them on the original image
+
+
+        :param request get_visual_object_bounds_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'GET', 'file')
+
     def grayscale_image(self, request):
         """Grayscale an existing image.
 
